#!/usr/bin/env python3

""" Download NLTK files """

import nltk


def main() -> None:
    """Main funtion - download NLTK files"""
    nltk.download("all")


if __name__ == "__main__":
    main()
